@@ -1,3 +1,4 @@
+# coding: utf-8
 
 from __future__ import print_function
 
@@ -8,16 +9,29 @@ import os
 import types
 
 try:
-    from ruamel.ordereddict import ordereddict
+    from ruamel.ordereddict import ordereddict  # type: ignore
 except:
     try:
         from collections import OrderedDict
     except ImportError:
-        from orderddict import OrderedDict
+        from orderddict import OrderedDict  # type: ignore
     # to get the right name import ... as ordereddict doesn't do that
 
-    class ordereddict(OrderedDict):
-        pass
+    class ordereddict(OrderedDict):   # type: ignore
+        if not hasattr(OrderedDict, 'insert'):
+            def insert(self, pos, key, value):
+                if pos >= len(self):
+                    self[key] = value
+                    return
+                od = ordereddict()
+                od.update(self)
+                for k in od:
+                    del self[k]
+                for index, old_key in enumerate(od):
+                    if pos == index:
+                        self[key] = value
+                    self[old_key] = od[old_key]
+
 
 PY2 = sys.version_info[0] == 2
 PY3 = sys.version_info[0] == 3
@@ -62,9 +76,10 @@ else:
     text_type = unicode
     binary_type = str
 
-    unichr = unichr  # to allow importing
-    import StringIO
-    StringIO = StringIO.StringIO
+    # to allow importing
+    unichr = unichr  # type: ignore
+    from StringIO import StringIO as _StringIO
+    StringIO = _StringIO
     import cStringIO
     BytesIO = cStringIO.StringIO
 
