@@ -1,31 +1,27 @@
+# coding: utf-8
+
 from __future__ import absolute_import
 from __future__ import print_function
 
-__all__ = ['BaseRepresenter', 'SafeRepresenter', 'Representer',
-           'RepresenterError', 'RoundTripRepresenter']
-
-try:
-    from .error import *
-    from .nodes import *
-    from .compat import text_type, binary_type, to_unicode, PY2, PY3, \
-                        ordereddict, nprint
-    from .scalarstring import *
-except (ImportError, ValueError):  # for Jython
-    from ruamel.yaml.error import *
-    from ruamel.yaml.nodes import *
-    from ruamel.yaml.compat import text_type, binary_type, to_unicode, PY2, \
-                        PY3, ordereddict, nprint
-    from ruamel.yaml.scalarstring import *
+from typing import Dict, Any   # NOQA
 
+from ruamel.yaml.error import *                       # NOQA
+from ruamel.yaml.nodes import *                       # NOQA
+from ruamel.yaml.compat import text_type, binary_type, to_unicode, PY2, PY3, ordereddict
+from ruamel.yaml.scalarstring import *                # NOQA
 
 import datetime
 import sys
 import types
 if PY3:
-    import copyreg
+    import copyreg  # type: ignore
     import base64
 else:
-    import copy_reg as copyreg
+    import copy_reg as copyreg  # type: ignore
+
+
+__all__ = ['BaseRepresenter', 'SafeRepresenter', 'Representer',
+           'RepresenterError', 'RoundTripRepresenter']
 
 
 class RepresenterError(YAMLError):
@@ -34,8 +30,8 @@ class RepresenterError(YAMLError):
 
 class BaseRepresenter(object):
 
-    yaml_representers = {}
-    yaml_multi_representers = {}
+    yaml_representers = {}   # type: Dict[Any, Any]
+    yaml_multi_representers = {}  # type: Dict[Any, Any]
 
     def __init__(self, default_style=None, default_flow_style=None):
         self.default_style = default_style
@@ -107,12 +103,14 @@ class BaseRepresenter(object):
 
     @classmethod
     def add_representer(cls, data_type, representer):
+        # type: (Any, Any) -> None
         if 'yaml_representers' not in cls.__dict__:
             cls.yaml_representers = cls.yaml_representers.copy()
         cls.yaml_representers[data_type] = representer
 
     @classmethod
     def add_multi_representer(cls, data_type, representer):
+        # type: (Any, Any) -> None
         if 'yaml_multi_representers' not in cls.__dict__:
             cls.yaml_multi_representers = cls.yaml_multi_representers.copy()
         cls.yaml_multi_representers[data_type] = representer
@@ -198,7 +196,10 @@ class BaseRepresenter(object):
 class SafeRepresenter(BaseRepresenter):
 
     def ignore_aliases(self, data):
-        if data in [None, ()]:
+        # https://docs.python.org/3/reference/expressions.html#parenthesized-forms :
+        # "i.e. two occurrences of the empty tuple may or may not yield the same object"
+        # so "data is ()" should not be used
+        if data is None or data == ():
             return True
         if isinstance(data, (binary_type, text_type, bool, int, float)):
             return True
@@ -574,13 +575,8 @@ Representer.add_multi_representer(object,
                                   Representer.represent_object)
 
 
-try:
-    from .comments import CommentedMap, CommentedOrderedMap, CommentedSeq, \
-    CommentedSet, comment_attrib, merge_attrib
-except ImportError:  # for Jython
-    from ruamel.yaml.comments import CommentedMap, CommentedOrderedMap, \
-           CommentedSeq, CommentedSet, comment_attrib, merge_attrib
-
+from ruamel.yaml.comments import CommentedMap, CommentedOrderedMap, \
+    CommentedSeq, CommentedSet, comment_attrib, merge_attrib    # NOQA
 
 
 class RoundTripRepresenter(SafeRepresenter):
@@ -605,6 +601,22 @@ class RoundTripRepresenter(SafeRepresenter):
         tag = u'tag:yaml.org,2002:str'
         return self.represent_scalar(tag, data, style=style)
 
+    def represent_single_quoted_scalarstring(self, data):
+        tag = None
+        style = "'"
+        if PY2 and not isinstance(data, unicode):
+            data = unicode(data, 'ascii')
+        tag = u'tag:yaml.org,2002:str'
+        return self.represent_scalar(tag, data, style=style)
+
+    def represent_double_quoted_scalarstring(self, data):
+        tag = None
+        style = '"'
+        if PY2 and not isinstance(data, unicode):
+            data = unicode(data, 'ascii')
+        tag = u'tag:yaml.org,2002:str'
+        return self.represent_scalar(tag, data, style=style)
+
     def represent_sequence(self, tag, sequence, flow_style=None):
         value = []
         # if the flow_style is None, the flow style tacked on to the object
@@ -818,8 +830,23 @@ class RoundTripRepresenter(SafeRepresenter):
                     node_value.style):
                 best_style = False
             value.append((node_key, node_value))
+        best_style = best_style
         return node
 
+    def represent_dict(self, data):
+        """write out tag if saved on loading"""
+        try:
+            t = data.tag.value
+        except AttributeError:
+            t = None
+        if t:
+            while t and t[0] == '!':
+                t = t[1:]
+            tag = 'tag:yaml.org,2002:' + t
+        else:
+            tag = u'tag:yaml.org,2002:map'
+        return self.represent_mapping(tag, data)
+
 
 RoundTripRepresenter.add_representer(type(None),
                                      RoundTripRepresenter.represent_none)
@@ -828,15 +855,27 @@ RoundTripRepresenter.add_representer(
     PreservedScalarString,
     RoundTripRepresenter.represent_preserved_scalarstring)
 
+RoundTripRepresenter.add_representer(
+    SingleQuotedScalarString,
+    RoundTripRepresenter.represent_single_quoted_scalarstring)
+
+RoundTripRepresenter.add_representer(
+    DoubleQuotedScalarString,
+    RoundTripRepresenter.represent_double_quoted_scalarstring)
+
 RoundTripRepresenter.add_representer(CommentedSeq,
                                      RoundTripRepresenter.represent_list)
 
 RoundTripRepresenter.add_representer(CommentedMap,
                                      RoundTripRepresenter.represent_dict)
 
-RoundTripRepresenter.add_representer(
-    CommentedOrderedMap,
-    RoundTripRepresenter.represent_ordereddict)
+RoundTripRepresenter.add_representer(CommentedOrderedMap,
+                                     RoundTripRepresenter.represent_ordereddict)
+
+if sys.version_info >= (2, 7):
+    import collections
+    RoundTripRepresenter.add_representer(collections.OrderedDict,
+                                         RoundTripRepresenter.represent_ordereddict)
 
 RoundTripRepresenter.add_representer(CommentedSet,
                                      RoundTripRepresenter.represent_set)
